@@ -1,7 +1,8 @@
-from .functions import *
+from .functions import MyClass
+from .functions import Mykonos
 import requests 
 
-__version__ = "0.0.6"
+__version__ = "0.0.9"
 
 __url__ = "https://api.adviceslip.com/advice"
 
